FED3Bandit
============

FED3Bandit is an implementation of the two-armed bandit task that that uses the open-source FED3 device. For more information on FED3Bandit visit: https://fed3bandit.readthedocs.io/en/latest/index.html